    using UnityEngine;

    [RequireComponent (typeof (BoxCollider2D))]
    [RequireComponent (typeof (SoundController))]
    public class Monstro : MonoBehaviour, IImprevisto {
        public Movable movedor { get; set; }
        public EnumFerramentaImprevisto matchFerramentaImprevisto { get; set; }
        public int solucaoCurrentAmount { get; set; }
        public bool solucionado { get; set; }

        private SoundController _soundController;

        private Animator animator;
        private SpriteRenderer spriteRenderer;
        private bool canTakeHit = true;

        [TooltipAttribute ("Quantos do target para dar como resolvido")]
        public int solucaoTargetAmount;

        public Sprite monsterKilledSprite;
        private GameObject currentObjectColliding;

        void Start () {
            _soundController = GetComponent<SoundController> ();
            _soundController.playSound (0, 0.5f);

            spriteRenderer = GetComponent<SpriteRenderer> ();
            animator = GetComponent<Animator> ();

            matchFerramentaImprevisto = EnumFerramentaImprevisto.monstro;
        }

        // Update is called once per frame
        void Update () {
            UpdateProgress ();
        }

        public bool CheckSolucionado () {
            return solucionado;
        }

        public void UpdateProgress () {

            if (currentObjectColliding == null || solucionado) return;
            IFerramenta arma = currentObjectColliding.GetComponent<IFerramenta> ();
            if (arma == null) return;

            if (matchFerramentaImprevisto == arma.matchFerramentaImprevisto && !arma.movedor.isDragging && canTakeHit) {
                solucaoCurrentAmount++;
                arma.PushAway ();
                canTakeHit = false;
                animator.SetBool ("TakeHit", true);
            }

            if (solucaoCurrentAmount >= solucaoTargetAmount) {
                spriteRenderer.sprite = monsterKilledSprite;
                solucionado = true;
                animator.SetBool ("Killed", true);
            }
        }

        void OnTriggerEnter2D (Collider2D collider) {
            currentObjectColliding = collider.gameObject;
        }

        void OnTriggerExit2D (Collider2D collider) {
            currentObjectColliding = null;
        }

        void OnTakeHitAnimation () {
            canTakeHit = true;
            animator.SetBool ("TakeHit", false);
        }

        void OnFadeOutAnimationEnd () {
            MonsterManager.monsterManager.ResetNewMonster ();
            Destroy (this.gameObject);
        }
    }