using System;
using UnityEngine;
using UnityEngine.EventSystems;

[RequireComponent(typeof(BoxCollider2D))]
public class Movable : MonoBehaviour, IBeginDragHandler, IDragHandler, IEndDragHandler
{
    public static GameObject DraggedInstance;
    public bool isDragging { get; set; }

    //touch specific
    Vector3 _startPosition;
    Vector3 _offsetToMouse;
    float _zDistanceToCamera;

    //mouse specific
    private Vector3 screenPoint;
    private Vector3 offset;

    #region Movement

    private const float MarginX = 10;
    private const float MarginY = 100;

    private void FixedUpdate()
    {
        Camera camera = Camera.main;
        var screenPosition = camera.WorldToScreenPoint(transform.position);
        Vector2 minPoint = new Vector2(MarginX, MarginY);
        Vector2 maxPoint = new Vector2(Screen.width - MarginX, Screen.height - MarginY);

        Vector3 newPosition = camera.ScreenToWorldPoint(
            new Vector3(
                Mathf.Clamp(screenPosition.x, minPoint.x, maxPoint.x),
                Mathf.Clamp(screenPosition.y, minPoint.y, maxPoint.y),
                990f));

        transform.position = newPosition;
    }

    void OnMouseDown()
    {
        isDragging = true;
        offset = gameObject.transform.position -
                 Camera.main.ScreenToWorldPoint(
                     new Vector3(Input.mousePosition.x, Input.mousePosition.y, screenPoint.z));
    }

    void OnMouseDrag()
    {
        Vector3 curScreenPoint = new Vector3(Input.mousePosition.x, Input.mousePosition.y, screenPoint.z);
        Vector3 curPosition = Camera.main.ScreenToWorldPoint(curScreenPoint) + offset;
        transform.position = curPosition;
    }

    void OnMouseUp()
    {
        isDragging = false;
    }

    public void OnBeginDrag(PointerEventData eventData)
    {
        isDragging = true;
        DraggedInstance = gameObject;
        _startPosition = transform.position;
        _zDistanceToCamera = Mathf.Abs(_startPosition.z - Camera.main.transform.position.z);

        _offsetToMouse = _startPosition - Camera.main.ScreenToWorldPoint(
                             new Vector3(Input.mousePosition.x, Input.mousePosition.y, _zDistanceToCamera)
                         );
    }

    public void OnDrag(PointerEventData eventData)
    {
        if (Input.touchCount > 1)
            return;

        transform.position = Camera.main.ScreenToWorldPoint(
                                 new Vector3(Input.mousePosition.x, Input.mousePosition.y, _zDistanceToCamera)
                             ) + _offsetToMouse;
    }

    public void OnEndDrag(PointerEventData eventData)
    {
        isDragging = false;
//        NotifyEndDrag();
        DraggedInstance = null;
        _offsetToMouse = Vector3.zero;
    }

/*    private void NotifyEndDrag()
    {
        Debug.Log("Notification");
        gameObject.SendMessage("UpdateProgress",SendMessageOptions.DontRequireReceiver);
    }*/

    #endregion
}
