using System.Collections;
using UnityEngine;
using UnityEngine.SceneManagement;

namespace _Scripts.Common
{
    public class SceneLoader : MonoBehaviour
    {
        public static SceneLoader Instance
        {
            get
            {
                if (instance != null)
                {
                    return instance;
                }

                GameObject container = Instantiate(new GameObject("SceneLoader"));
                instance = container.AddComponent<SceneLoader>();
                return instance;
            }
        }

        private static SceneLoader instance;

        public static void LoadSceneWithFade(string scenePath)
        {
            SceneManager.LoadScene(scenePath);
            //Instance.StartCoroutine(Instance.RunFadeRoutine(scenePath));
        }

        private IEnumerator RunFadeRoutine(string sceneName)
        {
            // Fade out
            FadeOverlay overlayPrefab = Resources.Load<FadeOverlay>("FadeOverlay");
            FadeOverlay fadeInstance = Instantiate(overlayPrefab);
            DontDestroyOnLoad(fadeInstance);
            yield return fadeInstance.FadeOut();

            // Wait until the asynchronous scene fully loads
            AsyncOperation asyncLoad = SceneManager.LoadSceneAsync(sceneName, LoadSceneMode.Single);
            while (!asyncLoad.isDone)
            {
                yield return null;
            }

            // Fade In
            yield return fadeInstance.FadeIn();
            Destroy(fadeInstance.gameObject);
        }

        private void Awake()
        {
            DontDestroyOnLoad(gameObject);
        }
    }
}
