﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class HubController : MonoBehaviour {
    public static HubController hubController;

    [SerializeField] public GameObject hubObject;
    [SerializeField] private GameObject hubReturnGameObject;
    [SerializeField] private GameObject aboveDoor, underDoor;
    [SerializeField] private List<GameObject> playerButtonsArray;
    [SerializeField] private List<GameObject> playerModulesArray;
    [SerializeField] private GameObject[] itemSlotList;

    public bool IsInHub { get; set; }

    private string currentPlayer;

    [SerializeField] private Button hubReturnButton;
    private Dictionary<string, GameObject> playerModules = new Dictionary<string, GameObject> ();

    private void Awake () {
        hubController = this;

        hubReturnButton = hubReturnGameObject.GetComponent<Button> ();

        playerModules.Add ("A", playerModulesArray[0]);
        playerModules.Add ("B", playerModulesArray[1]);
        playerModules.Add ("C", playerModulesArray[2]);
        playerModules.Add ("D", playerModulesArray[3]);
    }

    public void OnPlayerButtonClick (string playerId) {
        hubObject.SetActive (false);
        // hubReturnButton.interactable = true;
        OpenDoors ();
        ShowPlayerModule (playerId);
    }

    public void OnHUBButtonClick () {
        // hubReturnButton.interactable = false;
        CloseDoors ();
        HideCurrentPlayerModule ();
    }

    public void HideCurrentPlayerModule () {
        playerModules[currentPlayer].SetActive (false);
        currentPlayer = "NOBODY";
        //ItemsController.itemsController.EnableAllSlots ();
    }

    public void ShowPlayerModule (string playerId) {
        currentPlayer = playerId;
        playerModules[currentPlayer].SetActive (true);
        //ItemsController.itemsController.DisableAllSlots ();
    }

    public GameObject GetCurrentModuleObject () {
        if (currentPlayer == "NOBODY")
            return this.gameObject;

        return playerModules[currentPlayer];
    }

    private void OpenDoors () {
        aboveDoor.GetComponent<Animator> ().SetBool ("ClosedDoor", false);
        underDoor.GetComponent<Animator> ().SetBool ("ClosedDoor", false);
    }

    private void CloseDoors () {
        underDoor.SetActive (true);
        aboveDoor.GetComponent<Animator> ().SetBool ("ClosedDoor", true);
        underDoor.GetComponent<Animator> ().SetBool ("ClosedDoor", true);
    }

}