﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class ItemSlotController : MonoBehaviour {
    private HubController hubController;
    private bool slotHasItem = false;
    private GameObject itemInSlot;
    [SerializeField] private GameObject slotLock;
    [SerializeField] private Image littleBeltImage;
    private Sprite defaultLittleBeltImage;

    private void Awake () {
        hubController = GameObject.FindObjectOfType<HubController> ();
        defaultLittleBeltImage = littleBeltImage.sprite;
    }

    public void EnableLock () {
        slotLock.SetActive (true);
    }

    public void DisableLock () {
        slotLock.SetActive (false);
    }

    private void OnTriggerStay2D (Collider2D other) {
        if (slotHasItem)
            return;

        var movable = other.GetComponent<Movable> ();
        if (movable == null || movable.isDragging) {
            return;
        }

        var storable = other.GetComponent<StorableItem> ();
        if (storable == null) {
            return;
        }

        storable.StoreItem ();

        slotHasItem = true;
        itemInSlot = other.gameObject;
        itemInSlot.gameObject.transform.SetParent (this.gameObject.transform);
        itemInSlot.transform.position = this.gameObject.transform.position;
        itemInSlot.transform.rotation = this.gameObject.transform.rotation;
    }

    private void OnTriggerExit2D (Collider2D other) {
        if (!slotHasItem)
            return;

        var movable = other.GetComponent<Movable> ();
        if (movable == null || !movable.isDragging) {
            return;
        }

        var storable = other.GetComponent<StorableItem> ();
        if (storable == null) {
            return;
        }

        storable.TakeItem ();

        itemInSlot.transform.SetParent (hubController.GetCurrentModuleObject ().transform);
        slotHasItem = false;
        itemInSlot = null;
    }

}