﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class TimerBehavior : MonoBehaviour {
    public static TimerBehavior timerBehavior;
    public float totalGameTime, extraSpeed;
    public Text timerText;
    public GameObject ship, sun, monster;

    public float time, totalDistance, distanceStep, startTime, monsterTime;
    private RectTransform shipRectTransform;
    private Vector3 shipInitialLocalPosition, shipEndLocalPosition;

    void Start () {
        if (timerBehavior == null) {
            timerBehavior = this;
        } else {
            Destroy (this);
        }

        time = totalGameTime;
        startTime = Time.time;
        // timerText.text = "00:00";

        shipRectTransform = ship.GetComponent<RectTransform> ();
        shipInitialLocalPosition = shipRectTransform.localPosition;
        shipEndLocalPosition = sun.GetComponent<RectTransform> ().localPosition;
        totalDistance = Mathf.Abs (shipInitialLocalPosition.x) + Mathf.Abs (shipEndLocalPosition.x);
        distanceStep = totalDistance / totalGameTime;
    }

    void Update () {
        time = time - Time.deltaTime * 2000;
        UpdateShipPosition ();
        // if (timerText != null) {
        //     time -= Time.deltaTime;

        //     // For debug purposes
        //     // string minutes = Mathf.Floor (time / 60).ToString ("00");
        //     // string seconds = (time % 60).ToString ("00");
        //     // string fraction = ((time * 100) % 100).ToString ("000");
        //     // timerText.text = minutes.ToString () + ":" + seconds;
        //     UpdateShipPosition ();
        // }
    }

    private void UpdateShipPosition () {
        Vector3 currentPosition = GetShipCurrentPosition ();
        // Debug.Log (currentPosition);
        ship.GetComponent<RectTransform> ().localPosition = currentPosition;
        monster.GetComponent<RectTransform> ().localPosition = currentPosition;
    }

    private Vector3 GetShipCurrentPosition () {
        float percentage = GetPercentage ();
        // Debug.Log (percentage);
        float currentXPosition = shipInitialLocalPosition.x + (totalDistance * percentage);
        Vector3 currentPosition = new Vector3 (currentXPosition, shipInitialLocalPosition.y, shipInitialLocalPosition.z);
        return currentPosition;
    }

    public float GetPercentage () {
        float passedTime = Time.time - startTime + monsterTime;
        float percentage = 1 - ((totalGameTime - passedTime) / totalGameTime);
        return Mathf.Min (1, percentage);
    }

    public void IncreaseTotalGameTime (float extraTime) {
        totalGameTime += time;
    }

    public bool IsTimeOver () {
        return 1 == GetPercentage ();
    }

    public void SpeedUp (float extraTime) {
        monsterTime = monsterTime + extraTime;
    }

}